colour_hdri.process Package — Colour - HDRI 0.1.0 documentation

# colour_hdri.process Package

## Sub-Modules

- colour_hdri.process.conversion Module
  - Conversion Process

## Module Contents

`colour_hdri.process.` `convert_raw_files_to_dng_files`(raw_files, output_directory)

  Converts given raw files to dng files using given output directory.

  Parameters: | raw_files (array_like) – Raw files to convert to dng files. output_directory (unicode) – Output directory.
  Returns: | dng files.
  Return type: | list

`colour_hdri.process.` `convert_dng_files_to_intermediate_files`(dng_files, output_directory, demosaicing=False)

  Converts given dng files to intermediate tiff files using given output directory.

  Parameters: | dng_files (array_like) – dng files to convert to intermediate tiff files. output_directory (str) – Output directory. demosaicing (bool) – Perform demosaicing on conversion.
  Returns: | Intermediate tiff files.
  Return type: | list